__version__="4.6.0"
__copyright__="Copyright (c) 2001 - 2023 The SCons Foundation"
__developer__="bdbaddog"
__date__="Sun, 19 Nov 2023 17:22:20 -0700"
__buildsys__="M1Dog2021"
__revision__="e5eef322a4a727b96358a436dca46e8085ac8692"
__build__="e5eef322a4a727b96358a436dca46e8085ac8692"
# make sure compatibility is always in place
import SCons.compat  # noqa